==> xlniuxdata-vipgame-1.0.47-20160205.044215-5-sources.jar: com/xunlei/niux/data/vipgame/dao/games/GamesDaoImpl.java <==
package com.xunlei.niux.data.vipgame.dao.games;

import com.ferret.common.dao.BaseDaoImpl;
import com.xunlei.niux.data.vipgame.dto.MobileGameDTO;
import com.xunlei.niux.data.vipgame.dto.game.GameDTO;
import com.xunlei.niux.data.vipgame.dto.game.KuaiWanGameDTO;
import com.xunlei.niux.data.vipgame.vo.Games;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.jdbc.core.RowCallbackHandler;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by jamesjxin on 14-6-25.
 */
public class GamesDaoImpl extends BaseDaoImpl implements GamesDao{

    @Override
    public List<Games> queryGames(String keyWord,int limit) {
        String sql = "select * from games where gameName like ? and status = '1' ";
          sql += " and (clientType = 0 or clientType = 1) order by inputTime desc limit "+limit;        

        final List<Games> gamesList = new ArrayList<Games>();

        getJdbcTemplate().query(sql, new Object[]{keyWord+"%"}, new RowCallbackHandler() {
            @Override
            public void processRow(ResultSet resultSet) throws SQLException {
                Games game = new Games();
                game.setSeqId(resultSet.getLong("seqId"));
                game.setGameId(resultSet.getString("gameId"));
                game.setGameNo(resultSet.getString("gameNo"));
                game.setGameName(resultSet.getString("gameName"));
                game.setOfficialWebSite(resultSet.getString("officialWebSite"));
                gamesList.add(game);
            }
        });

        return gamesList;
    }

    @Override
    public List<GameDTO> queryWebGamesByKeyWord(String keyWord) {
        String sql = "select gameId,gameNo,gameName,gameFeature,officialWebSite,picUrl,smallPicUrl,gameDesc,summary,packageName,'' downLoadUrl,'' downloadNum,'' mulPhotoUrl,'' appSize,displayOrder,"
        		//增加是否有礼包(hasGift),最新或者最热(isHotOrNew),是否独家(runType)
        		+ "CASE WHEN (games.isHot+games.isNew)>1 then 1 ELSE 0  END isHotOrNew,games.runType,games.hasGift,"
        		+ "mobileGameType" +
                " from games where gameName like ? and status = '1' and (clientType = 0 or clientType = 1) ";
        List<Object> list = new ArrayList<Object>();
        list.add("%"+keyWord+"%");
        List<GameDTO> gamesList = executeQuery(GameDTO.class,sql,list);

        return gamesList;
    }

    @Override
    public List<GameDTO> queryAppGamesByKeyWord(String keyWord) {
       /* backup20151021
       String sql = "select games.gameId,games.gameNo,games.gameName,games.gameFeature,games.officialWebSite,games.picUrl,games.smallPicUrl,games.gameDesc,games.summary,games.packageName,newcommonspreadinfo.shortUrl downLoadUrl,games.downloadNum,newcommonspreadinfo.muliPhotoUrl mulPhotoUrl,displayOrder,games.appSize,"
        		//增加是否有礼包(hasGift),最新或者最热(isHotOrNew),是否独家(runType)
        		+ "CASE WHEN (games.isHot+games.isNew)>1 then 1 ELSE 0  END isHotOrNew,games.runType,games.hasGift,"
        		+ "mobileGameType from games\n" +
                "left join \n" +
                "(select a.* from commonspreadinfo a \n" +
                "inner join \n" +
                "(select gameId,max(seqId) seqId from commonspreadinfo group by gameId) b \n" +
                "on a.gameId = b.gameId and a.seqId = b.seqId\n" +
                ") newcommonspreadinfo\n" +
                " on games.gameId = newcommonspreadinfo.gameId\n" +
                "where gameName like ? and status = '1' and clientType = 3\n" +
                "union \n" +
                "select gameId,gameNo,gameName,gameFeature,'' officialWebSite,picUrl,iconUrl smallPicUrl,gameDesc,summary,packageName,downLoadUrl,downloadNum,mulPhotoUrl,displayOrder,cpsSize appSize,"
                //增加是否有礼包(hasGift，暂无此字段默认为0),最新或者最热(isHotOrNew，暂无此字段默认为0),是否独家(runType，暂无此字段默认为100)
              	+ "0 isHotOrNew,100 runType,hasGift,"
                + "mobileGameType from cpsgames where gameName like ? and status = 1 order by displayOrder desc;";*/

        String sql="SELECT games.gameId,games.gameNo,games.gameName,games.gameFeature,games.officialWebSite,games.picUrl,games.smallPicUrl,games.gameDesc,games.summary,games.packageName,notcpsgames.url AS downLoadUrl,notcpsgames.url AS mulPhotoUrl,games.downloadNum,displayOrder,games.appSize,\n" +
                "CASE WHEN (games.isHot+games.isNew)>1 THEN 1 ELSE 0  END isHotOrNew,games.runType,games.hasGift,\n" +
                "mobileGameType FROM games\n" +
                "RIGHT JOIN\n" +
                "(SELECT a.gameId AS gameid,a.shortUrl AS url FROM commonspreadinfo a INNER JOIN (SELECT gameId,MAX(seqId) seqId FROM commonspreadinfo GROUP BY gameId) b ON a.gameId = b.gameId AND a.seqId = b.seqId\n" +
                "UNION\n" +
                "SELECT gameidbytuijian AS gameid,linkurl AS url FROM linkinfo WHERE linklocid=1601 AND gameidbytuijian NOT LIKE 'c%' AND NOT EXISTS (SELECT 1 FROM commonspreadinfo c WHERE c.gameId=gameidbytuijian )) notcpsgames\n" +
                "ON games.gameId = notcpsgames.gameId\n" +
                "WHERE gameName LIKE ? AND STATUS = '1' AND clientType = 3\n" +
                "\n" +
                "UNION\n" +
                "\n" +
                "SELECT gameId,gameNo,gameName,gameFeature,'' officialWebSite,picUrl,iconUrl smallPicUrl,gameDesc,summary,packageName,cps.linkurl AS downLoadUrl,mulPhotoUrl,downloadNum,displayOrder,cpsSize appSize,\n" +
                "0 isHotOrNew,100 runType,hasGift,\n" +
                "mobileGameType FROM cpsgames \n" +
                "INNER JOIN \n" +
                "(SELECT gameidbytuijian,linkurl FROM linkinfo WHERE linklocid=1601 AND gameidbytuijian LIKE 'c%') cps ON cpsgames.gameId=cps.gameidbytuijian\n" +
                "WHERE gameName LIKE ? AND STATUS = 1 ORDER BY displayOrder DESC;";

        List<Object> list = new ArrayList<Object>();
        list.add("%"+keyWord+"%");
        list.add("%"+keyWord+"%");
        List<GameDTO> gamesList = executeQuery(GameDTO.class,sql,list);

        return gamesList;
    }

    @Override
    public List<GameDTO> getAllValidWebGames() {
    	String sql = "select gameId,gameNo,gameName,gameFeature,officialWebSite,picUrl,smallPicUrl,gameDesc,summary,packageName,'' downLoadUrl,'' downloadNum,'' mulPhotoUrl,'' appSize,displayOrder,"
        		//增加是否有礼包(hasGift),最新或者最热(isHotOrNew),是否独家(runType)
        		+ "CASE WHEN (games.isHot+games.isNew)>1 then 1 ELSE 0  END isHotOrNew,games.runType,games.hasGift,"
        		+ "mobileGameType" +
                " from games where status = '1' and (clientType = 0 or clientType = 1) ";
        List<Object> list = new ArrayList<Object>();
        List<GameDTO> gamesList = executeQuery(GameDTO.class,sql,list);

        return gamesList;
    }

    @Override
    public List<GameDTO> getAllValidAppGames() {
    	String sql = " select games.gameId,games.gameNo,games.gameName,games.gameFeature,games.officialWebSite,games.picUrl,games.smallPicUrl,games.gameDesc,games.summary,games.packageName,newcommonspreadinfo.shortUrl downLoadUrl,games.downloadNum,newcommonspreadinfo.muliPhotoUrl mulPhotoUrl,displayOrder,games.appSize,"
        		//增加是否有礼包(hasGift),最新或者最热(isHotOrNew),是否独家(runType)
        		+ "CASE WHEN (games.isHot+games.isNew)>1 then 1 ELSE 0  END isHotOrNew,games.runType,games.hasGift,"
        		+ "mobileGameType from games\n" +
                "inner join \n" +
                "(select a.* from commonspreadinfo a \n" +
                "inner join \n" +
                "(select gameId,max(seqId) seqId from commonspreadinfo group by gameId) b \n" +
                "on a.gameId = b.gameId and a.seqId = b.seqId\n" +
                ") newcommonspreadinfo\n" +
                " on games.gameId = newcommonspreadinfo.gameId\n" +
                "where status = '1' and clientType = 3\n" +
                "union \n" +
                "select gameId,gameNo,gameName,gameFeature,'' officialWebSite,picUrl,iconUrl smallPicUrl,gameDesc,summary,packageName,downLoadUrl,downloadNum,mulPhotoUrl,displayOrder,cpsSize appSize,"
                //增加是否有礼包(hasGift，暂无此字段默认为0),最新或者最热(isHotOrNew，暂无此字段默认为0),是否独家(runType，暂无此字段默认为100)
                + "0 isHotOrNew,100 runType,hasGift,"
                + "mobileGameType from cpsgames where status = 1 order by displayOrder desc;";

        List<Object> list = new ArrayList<Object>();
        List<GameDTO> gamesList = executeQuery(GameDTO.class,sql,list);

        return gamesList;
    }

    @Override
    public List<MobileGameDTO> getAllMobileGames() {
        String sql = "SELECT s1.gameId,s1.gameNo,s1.gameName,s1.gameFeature featureId,s1.gameType typeId,s1.officialWebSite gameOfficialLink,ifnull(s1.smallPicUrl,'') icon,s2.linkurl downloadLink,s2.ext1  downloadNum,s1.displayOrder\n" +
                "FROM games s1 INNER JOIN (SELECT * FROM linkinfo WHERE linklocid='1601') s2\n" +
                "ON s1.gameId = s2.gameidbytuijian\n" +
                "WHERE s1.status=1 AND s1.clientType=3\n" +
                "union\n" +
                "select gameId,gameNo,gameName,gameFeature featureId,'' typdId,'' gameOfficialLink,ifnull(iconUrl,'') icon,downLoadUrl downloadLink,downloadNum,displayOrder\n" +
                "from cpsgames where status = 1\n" +
                "order by displayOrder desc";
        List<Object> list=new ArrayList<Object>();
        List<MobileGameDTO> bplist = executeQuery(MobileGameDTO.class, sql ,list);
        return bplist;
    }

    public Games getCurrentNewstMobileGame(){
        String sql = " select seqId,gameId,gameName,gameNo from games where gameId like '05%' order by gameId desc limit 1;";

        final List<Games> gamesList = new ArrayList<Games>();

        getJdbcTemplate().query(sql,  new RowCallbackHandler() {
            @Override
            public void processRow(ResultSet resultSet) throws SQLException {
                Games game = new Games();
                game.setSeqId(resultSet.getLong("seqId"));
                game.setGameId(resultSet.getString("gameId"));
                game.setGameNo(resultSet.getString("gameNo"));
                game.setGameName(resultSet.getString("gameName"));

                gamesList.add(game);
            }
        });
        if(CollectionUtils.isEmpty(gamesList)){
            return null;
        }
        return gamesList.get(0);
    }

    @Override
    public List<KuaiWanGameDTO> getKuaiwanWebGames(){
        String sql = "select games.gameId,gameNo,gameName,gameFeature,officialWebSite,picUrl,smallPicUrl,gameDesc,summary,packageName,'' downLoadUrl,'' downloadNum,'' mulPhotoUrl,'' appSize,displayOrder,mobileGameType,editTime,pics.pic1, pics.pic2, pics.pic3, pics.pic4, pics.pic5" +
                " from games left join mobilegamepics pics on games.gameId = pics.gameId where status = '1' and (clientType = 0 or clientType = 1) ";

        List<Object> list = new ArrayList<Object>();
        List<KuaiWanGameDTO> gamesList = executeQuery(KuaiWanGameDTO.class,sql,list);

        return gamesList;
    }

    @Override
    public List<KuaiWanGameDTO> getKuaiwanAppGames(){
        String sql = " select games.gameId,games.gameNo,games.gameName,games.gameFeature,games.officialWebSite,games.picUrl,games.smallPicUrl,games.gameDesc,games.summary,games.packageName,newcommonspreadinfo.shortUrl downLoadUrl,games.downloadNum,newcommonspreadinfo.muliPhotoUrl mulPhotoUrl,displayOrder,games.appSize,mobileGameType,games.editTime,pics.pic1, pics.pic2, pics.pic3, pics.pic4, pics.pic5 from games\n" +
                "inner join \n" +
                "(select a.* from commonspreadinfo a \n" +
                "inner join \n" +
                "(select gameId,max(seqId) seqId from commonspreadinfo group by gameId) b \n" +
                "on a.gameId = b.gameId and a.seqId = b.seqId\n" +
                ") newcommonspreadinfo\n" +
                " on games.gameId = newcommonspreadinfo.gameId\n" +
                "left join mobilegamepics pics\n" +
                "on games.gameId = pics.gameId\n" +
                "where status = '1' and clientType = 3\n" +
                "union \n" +
                "select cpsgames.gameId,gameNo,gameName,gameFeature,'' officialWebSite,picUrl,iconUrl smallPicUrl,gameDesc,summary,packageName,downLoadUrl,downloadNum,mulPhotoUrl,displayOrder,cpsSize appSize,mobileGameType,cpsgames.editTime,pics.pic1, pics.pic2, pics.pic3, pics.pic4, pics.pic5 from cpsgames left join mobilegamepics pics on cpsgames.gameId = pics.gameId where status = 1 order by displayOrder desc;";


        List<Object> list = new ArrayList<Object>();
        List<KuaiWanGameDTO> gamesList = executeQuery(KuaiWanGameDTO.class,sql,list);

        return gamesList;
    }

	@Override
	public List<Games> queryHlgGamesByKeyWord(String keyWord ,int limit) {
		String sql = "select * from games where gameName like ? and status = '1' ";
        sql += " and clientType = 4 order by inputTime desc limit "+limit;        

      final List<Games> gamesList = new ArrayList<Games>();

      getJdbcTemplate().query(sql, new Object[]{keyWord+"%"}, new RowCallbackHandler() {
          @Override
          public void processRow(ResultSet resultSet) throws SQLException {
              Games game = new Games();
              game.setSeqId(resultSet.getLong("seqId"));
              game.setGameId(resultSet.getString("gameId"));
              game.setGameNo(resultSet.getString("gameNo"));
              game.setGameName(resultSet.getString("gameName"));
              game.setOfficialWebSite(resultSet.getString("officialWebSite"));
              gamesList.add(game);
          }
      });

      return gamesList;
	}
}

==> xlniuxdata-vipgame-1.0.50-20160225.064314-2-sources.jar: com/xunlei/niux/data/vipgame/dao/games/GamesDaoImpl.java <==
package com.xunlei.niux.data.vipgame.dao.games;

import com.ferret.common.dao.BaseDaoImpl;
import com.xunlei.common.facade.IFacadeCommon;
import com.xunlei.niux.data.vipgame.dto.MobileGameDTO;
import com.xunlei.niux.data.vipgame.dto.game.GameDTO;
import com.xunlei.niux.data.vipgame.dto.game.KuaiWanGameDTO;
import com.xunlei.niux.data.vipgame.vo.Games;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.jdbc.core.RowCallbackHandler;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * Created by jamesjxin on 14-6-25.
 */
public class GamesDaoImpl extends BaseDaoImpl implements GamesDao{

    @Override
    public List<Games> queryGames(String keyWord,int limit) {
        String sql = "select * from games where gameName like ? and status = '1' ";
          sql += " and (clientType = 0 or clientType = 1) order by inputTime desc limit "+limit;        

        final List<Games> gamesList = new ArrayList<Games>();

        getJdbcTemplate().query(sql, new Object[]{keyWord+"%"}, new RowCallbackHandler() {
            @Override
            public void processRow(ResultSet resultSet) throws SQLException {
                Games game = new Games();
                game.setSeqId(resultSet.getLong("seqId"));
                game.setGameId(resultSet.getString("gameId"));
                game.setGameNo(resultSet.getString("gameNo"));
                game.setGameName(resultSet.getString("gameName"));
                game.setOfficialWebSite(resultSet.getString("officialWebSite"));
                gamesList.add(game);
            }
        });

        return gamesList;
    }

    @Override
    public List<GameDTO> queryWebGamesByKeyWord(String keyWord) {
        String sql = "select gameId,gameNo,gameName,gameFeature,officialWebSite,picUrl,smallPicUrl,gameDesc,summary,packageName,'' downLoadUrl,'' downloadNum,'' mulPhotoUrl,'' appSize,displayOrder,"
        		//增加是否有礼包(hasGift),最新或者最热(isHotOrNew),是否独家(runType)
        		+ "CASE WHEN (games.isHot+games.isNew)>1 then 1 ELSE 0  END isHotOrNew,games.runType,games.hasGift,"
        		+ "mobileGameType" +
                " from games where gameName like ? and status = '1' and (clientType = 0 or clientType = 1) ";
        List<Object> list = new ArrayList<Object>();
        list.add("%"+keyWord+"%");
        List<GameDTO> gamesList = executeQuery(GameDTO.class,sql,list);

        return gamesList;
    }

    @Override
    public List<GameDTO> queryAppGamesByKeyWord(String keyWord) {
       /* backup20151021
       String sql = "select games.gameId,games.gameNo,games.gameName,games.gameFeature,games.officialWebSite,games.picUrl,games.smallPicUrl,games.gameDesc,games.summary,games.packageName,newcommonspreadinfo.shortUrl downLoadUrl,games.downloadNum,newcommonspreadinfo.muliPhotoUrl mulPhotoUrl,displayOrder,games.appSize,"
        		//增加是否有礼包(hasGift),最新或者最热(isHotOrNew),是否独家(runType)
        		+ "CASE WHEN (games.isHot+games.isNew)>1 then 1 ELSE 0  END isHotOrNew,games.runType,games.hasGift,"
        		+ "mobileGameType from games\n" +
                "left join \n" +
                "(select a.* from commonspreadinfo a \n" +
                "inner join \n" +
                "(select gameId,max(seqId) seqId from commonspreadinfo group by gameId) b \n" +
                "on a.gameId = b.gameId and a.seqId = b.seqId\n" +
                ") newcommonspreadinfo\n" +
                " on games.gameId = newcommonspreadinfo.gameId\n" +
                "where gameName like ? and status = '1' and clientType = 3\n" +
                "union \n" +
                "select gameId,gameNo,gameName,gameFeature,'' officialWebSite,picUrl,iconUrl smallPicUrl,gameDesc,summary,packageName,downLoadUrl,downloadNum,mulPhotoUrl,displayOrder,cpsSize appSize,"
                //增加是否有礼包(hasGift，暂无此字段默认为0),最新或者最热(isHotOrNew，暂无此字段默认为0),是否独家(runType，暂无此字段默认为100)
              	+ "0 isHotOrNew,100 runType,hasGift,"
                + "mobileGameType from cpsgames where gameName like ? and status = 1 order by displayOrder desc;";*/

        String sql="SELECT games.gameId,games.gameNo,games.gameName,games.gameFeature,games.officialWebSite,games.picUrl,games.smallPicUrl,games.gameDesc,games.summary,games.packageName,notcpsgames.url AS downLoadUrl,notcpsgames.url AS mulPhotoUrl,games.downloadNum,displayOrder,games.appSize,\n" +
                "CASE WHEN (games.isHot+games.isNew)>1 THEN 1 ELSE 0  END isHotOrNew,games.runType,games.hasGift,\n" +
                "mobileGameType FROM games\n" +
                "RIGHT JOIN\n" +
                "(SELECT a.gameId AS gameid,a.shortUrl AS url FROM commonspreadinfo a INNER JOIN (SELECT gameId,MAX(seqId) seqId FROM commonspreadinfo GROUP BY gameId) b ON a.gameId = b.gameId AND a.seqId = b.seqId\n" +
                "UNION\n" +
                "SELECT gameidbytuijian AS gameid,linkurl AS url FROM linkinfo WHERE linklocid=1601 AND gameidbytuijian NOT LIKE 'c%' AND NOT EXISTS (SELECT 1 FROM commonspreadinfo c WHERE c.gameId=gameidbytuijian )) notcpsgames\n" +
                "ON games.gameId = notcpsgames.gameId\n" +
                "WHERE gameName LIKE ? AND STATUS = '1' AND clientType = 3\n" +
                "\n" +
                "UNION\n" +
                "\n" +
                "SELECT gameId,gameNo,gameName,gameFeature,'' officialWebSite,picUrl,iconUrl smallPicUrl,gameDesc,summary,packageName,cps.linkurl AS downLoadUrl,mulPhotoUrl,downloadNum,displayOrder,cpsSize appSize,\n" +
                "0 isHotOrNew,100 runType,hasGift,\n" +
                "mobileGameType FROM cpsgames \n" +
                "INNER JOIN \n" +
                "(SELECT gameidbytuijian,linkurl FROM linkinfo WHERE linklocid=1601 AND gameidbytuijian LIKE 'c%') cps ON cpsgames.gameId=cps.gameidbytuijian\n" +
                "WHERE gameName LIKE ? AND STATUS = 1 ORDER BY displayOrder DESC;";

        List<Object> list = new ArrayList<Object>();
        list.add("%"+keyWord+"%");
        list.add("%"+keyWord+"%");
        List<GameDTO> gamesList = executeQuery(GameDTO.class,sql,list);

        return gamesList;
    }

    @Override
    public List<GameDTO> getAllValidWebGames() {
    	String sql = "select gameId,gameNo,gameName,gameFeature,officialWebSite,picUrl,smallPicUrl,gameDesc,summary,packageName,'' downLoadUrl,'' downloadNum,'' mulPhotoUrl,'' appSize,displayOrder,"
        		//增加是否有礼包(hasGift),最新或者最热(isHotOrNew),是否独家(runType)
        		+ "CASE WHEN (games.isHot+games.isNew)>1 then 1 ELSE 0  END isHotOrNew,games.runType,games.hasGift,"
        		+ "mobileGameType" +
                " from games where status = '1' and (clientType = 0 or clientType = 1) ";
        List<Object> list = new ArrayList<Object>();
        List<GameDTO> gamesList = executeQuery(GameDTO.class,sql,list);

        return gamesList;
    }

    @Override
    public List<GameDTO> getAllValidAppGames() {
    	String sql = " select games.gameId,games.gameNo,games.gameName,games.gameFeature,games.officialWebSite,games.picUrl,games.smallPicUrl,games.gameDesc,games.summary,games.packageName,newcommonspreadinfo.shortUrl downLoadUrl,games.downloadNum,newcommonspreadinfo.muliPhotoUrl mulPhotoUrl,displayOrder,games.appSize,"
        		//增加是否有礼包(hasGift),最新或者最热(isHotOrNew),是否独家(runType)
        		+ "CASE WHEN (games.isHot+games.isNew)>1 then 1 ELSE 0  END isHotOrNew,games.runType,games.hasGift,"
        		+ "mobileGameType from games\n" +
                "inner join \n" +
                "(select a.* from commonspreadinfo a \n" +
                "inner join \n" +
                "(select gameId,max(seqId) seqId from commonspreadinfo group by gameId) b \n" +
                "on a.gameId = b.gameId and a.seqId = b.seqId\n" +
                ") newcommonspreadinfo\n" +
                " on games.gameId = newcommonspreadinfo.gameId\n" +
                "where status = '1' and clientType = 3\n" +
                "union \n" +
                "select gameId,gameNo,gameName,gameFeature,'' officialWebSite,picUrl,iconUrl smallPicUrl,gameDesc,summary,packageName,downLoadUrl,downloadNum,mulPhotoUrl,displayOrder,cpsSize appSize,"
                //增加是否有礼包(hasGift，暂无此字段默认为0),最新或者最热(isHotOrNew，暂无此字段默认为0),是否独家(runType，暂无此字段默认为100)
                + "0 isHotOrNew,100 runType,hasGift,"
                + "mobileGameType from cpsgames where status = 1 order by displayOrder desc;";

        List<Object> list = new ArrayList<Object>();
        List<GameDTO> gamesList = executeQuery(GameDTO.class,sql,list);

        return gamesList;
    }

    @Override
    public List<MobileGameDTO> getAllMobileGames() {
        String sql = "SELECT s1.gameId,s1.gameNo,s1.gameName,s1.gameFeature featureId,s1.gameType typeId,s1.officialWebSite gameOfficialLink,ifnull(s1.smallPicUrl,'') icon,s2.linkurl downloadLink,s2.ext1  downloadNum,s1.displayOrder\n" +
                "FROM games s1 INNER JOIN (SELECT * FROM linkinfo WHERE linklocid='1601') s2\n" +
                "ON s1.gameId = s2.gameidbytuijian\n" +
                "WHERE s1.status=1 AND s1.clientType=3\n" +
                "union\n" +
                "select gameId,gameNo,gameName,gameFeature featureId,'' typdId,'' gameOfficialLink,ifnull(iconUrl,'') icon,downLoadUrl downloadLink,downloadNum,displayOrder\n" +
                "from cpsgames where status = 1\n" +
                "order by displayOrder desc";
        List<Object> list=new ArrayList<Object>();
        List<MobileGameDTO> bplist = executeQuery(MobileGameDTO.class, sql ,list);
        return bplist;
    }

    public Games getCurrentNewstMobileGame(){
        String sql = " select seqId,gameId,gameName,gameNo from games where gameId like '05%' order by gameId desc limit 1;";

        final List<Games> gamesList = new ArrayList<Games>();

        getJdbcTemplate().query(sql,  new RowCallbackHandler() {
            @Override
            public void processRow(ResultSet resultSet) throws SQLException {
                Games game = new Games();
                game.setSeqId(resultSet.getLong("seqId"));
                game.setGameId(resultSet.getString("gameId"));
                game.setGameNo(resultSet.getString("gameNo"));
                game.setGameName(resultSet.getString("gameName"));

                gamesList.add(game);
            }
        });
        if(CollectionUtils.isEmpty(gamesList)){
            return null;
        }
        return gamesList.get(0);
    }

    @Override
    public List<KuaiWanGameDTO> getKuaiwanWebGames(){
        String sql = "select games.gameId,gameNo,gameName,gameFeature,officialWebSite,picUrl,smallPicUrl,gameDesc,summary,packageName,'' downLoadUrl,'' downloadNum,'' mulPhotoUrl,'' appSize,displayOrder,mobileGameType,editTime,pics.pic1, pics.pic2, pics.pic3, pics.pic4, pics.pic5" +
                " from games left join mobilegamepics pics on games.gameId = pics.gameId where status = '1' and (clientType = 0 or clientType = 1) ";

        List<Object> list = new ArrayList<Object>();
        List<KuaiWanGameDTO> gamesList = executeQuery(KuaiWanGameDTO.class,sql,list);

        return gamesList;
    }

    @Override
    public List<KuaiWanGameDTO> getKuaiwanAppGames(){
        String sql = " select games.gameId,games.gameNo,games.gameName,games.gameFeature,games.officialWebSite,games.picUrl,games.smallPicUrl,games.gameDesc,games.summary,games.packageName,newcommonspreadinfo.shortUrl downLoadUrl,games.downloadNum,newcommonspreadinfo.muliPhotoUrl mulPhotoUrl,displayOrder,games.appSize,mobileGameType,games.editTime,pics.pic1, pics.pic2, pics.pic3, pics.pic4, pics.pic5 from games\n" +
                "inner join \n" +
                "(select a.* from commonspreadinfo a \n" +
                "inner join \n" +
                "(select gameId,max(seqId) seqId from commonspreadinfo group by gameId) b \n" +
                "on a.gameId = b.gameId and a.seqId = b.seqId\n" +
                ") newcommonspreadinfo\n" +
                " on games.gameId = newcommonspreadinfo.gameId\n" +
                "left join mobilegamepics pics\n" +
                "on games.gameId = pics.gameId\n" +
                "where status = '1' and clientType = 3\n" +
                "union \n" +
                "select cpsgames.gameId,gameNo,gameName,gameFeature,'' officialWebSite,picUrl,iconUrl smallPicUrl,gameDesc,summary,packageName,downLoadUrl,downloadNum,mulPhotoUrl,displayOrder,cpsSize appSize,mobileGameType,cpsgames.editTime,pics.pic1, pics.pic2, pics.pic3, pics.pic4, pics.pic5 from cpsgames left join mobilegamepics pics on cpsgames.gameId = pics.gameId where status = 1 order by displayOrder desc;";


        List<Object> list = new ArrayList<Object>();
        List<KuaiWanGameDTO> gamesList = executeQuery(KuaiWanGameDTO.class,sql,list);

        return gamesList;
    }

	@Override
	public List<Games> queryHlgGamesByKeyWord(String keyWord ,int limit) {
		String sql = "select * from games where gameName like ? and status = '1' ";
        sql += " and clientType = 4 order by inputTime desc limit "+limit;        

      final List<Games> gamesList = new ArrayList<Games>();

      getJdbcTemplate().query(sql, new Object[]{keyWord+"%"}, new RowCallbackHandler() {
          @Override
          public void processRow(ResultSet resultSet) throws SQLException {
              Games game = new Games();
              game.setSeqId(resultSet.getLong("seqId"));
              game.setGameId(resultSet.getString("gameId"));
              game.setGameNo(resultSet.getString("gameNo"));
              game.setGameName(resultSet.getString("gameName"));
              game.setOfficialWebSite(resultSet.getString("officialWebSite"));
              gamesList.add(game);
          }
      });

      return gamesList;
	}

    private String getDateValue(){
        String boxGuessDate = IFacadeCommon.INSTANCE.getLibconfigValueByConfigNo("boxGuessDate");
        return boxGuessDate;
    }

    @Override
    public List<Games> getBoxMoreGames(Games games, int type, String [] order,Boolean limitTime) {
        List<Object> paramList = new ArrayList<Object>();
        String sql ="\tselect   from games  \n" +
                "\tINNER JOIN gameservers on games.gameId = gameservers.gameId  \n" +
                "\tINNER JOIN \n" +
                "\t(SELECT MIN(gms.openTime) AS opentime, gms.gameid, gms.seqId FROM gameservers gms \n" +
                "\tINNER JOIN games ON games. STATUS = 1 AND ( games.clientType = 0 OR games.clientType = 1 ) AND games.gameid = gms.gameid \n" +
                "\tWHERE openstatus = 1 GROUP BY gameid) gs on gs.seqId = gameservers.seqId  \n" +
                "\tLEFT JOIN boxgamesextinfo binfo on binfo.gameNo=games.gameId and binfo.status=1 \n" +
                "\twhere   1=1 ";
        if(limitTime){
            sql+="( gameservers.openTime >=DATE_ADD(CURDATE(), INTERVAL -\"+getDateValue()+\" MONTH) or binfo.isContain=1  )";
        }
        if(games!=null){
            if(StringUtils.isNotEmpty(games.getStatus())){
                sql+=" and games.status = ?";
                paramList.add(games.getStatus());
            }
        }

        if(type==1){
            sql += "and games.clientType not in (?,?)";
            paramList.add(2);
            paramList.add(3);
        }else if(type==2){
            sql += "and games.clientType not in (?,?)";
            paramList.add(2);
            paramList.add(3);
        }

        String orderStr = "";
        for(String str : order){
            if(StringUtils.isEmpty(str)){
                continue;
            }
            String[] split = str.split("_");
            if(split.length==1){
                orderStr +=split[0]+",";
            }else if(split.length==2){
                orderStr +=split[0]+" "+split[1]+",";
            }
        }
        if(orderStr.length()>0){
            sql+=orderStr.substring(0,orderStr.length()-1);
        }

        List<Games> bySql = findBySql(Games.class, sql, paramList);

        return bySql;
    }

    @Override
    public List<Games> queryRecommendPhoneGamelist(){

        String sql = "select * from games where clientType=4 and isHot=1 order by displayOrder desc, privilegeType desc";
        List<Games> gamesList = executeQuery(Games.class,sql,new ArrayList<Object>());

        return gamesList;
    }

    @Override
    public List<Games> queryNewHLGGamelist(){
        String sql = "select * from games where clientType=4 and isNew=1 order by displayOrder desc, privilegeType desc";
        List<Games> gamesList = executeQuery(Games.class,sql,new ArrayList<Object>());

        return gamesList;
    }

    @Override
    public List<Games> queryRecommendHLGGamelist(){
        String sql = "select * from games where clientType=3 order by displayOrder desc";
        List<Games> gamesList = executeQuery(Games.class,sql,new ArrayList<Object>());

        return gamesList;
    }
}
